==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GdkPixbufDecoder__24ImageFormatSpec.h <==
// public class gnu.java.awt.peer.gtk.GdkPixbufDecoder$ImageFormatSpec

// class file dependencies
// @dep_class acb5dfed66831b5c gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec_H_
#define _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ArrayList$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_refs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$refs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$nonrefs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vmethods	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtable	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtype	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method$_init$73d32b75516f7b43(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method$addExtension$b36543637310fb2e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method$addMimeType$5840c665fb7ce654(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method_info$addExtension$b36543637310fb2e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method_info$addMimeType$5840c665fb7ce654;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vmethods {
	void	(*addExtension$b36543637310fb2e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *, struct _jc_java_lang_String$object *);
	void	(*addMimeType$5840c665fb7ce654)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *, struct _jc_java_lang_String$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vmethods	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_util_ArrayList$object	*mimeTypes;
	struct _jc_java_util_ArrayList$object	*extensions;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$refs {
    _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_refs	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_nonrefs {
	jboolean	writable;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_nonrefs	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object {
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtype _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GdkPixbufDecoder__24ImageFormatSpec.h <==
// public class gnu.java.awt.peer.gtk.GdkPixbufDecoder$ImageFormatSpec

// class file dependencies
// @dep_class acb5dfed66831b5c gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec_H_
#define _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_ArrayList$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_refs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$refs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$nonrefs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vmethods	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtable	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtype	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method$_init$73d32b75516f7b43(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method$addExtension$b36543637310fb2e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method$addMimeType$5840c665fb7ce654(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method_info$addExtension$b36543637310fb2e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method_info$addMimeType$5840c665fb7ce654;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vmethods {
	void	(*addExtension$b36543637310fb2e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*addMimeType$5840c665fb7ce654)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vmethods	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_refs {
	struct _jc_java_lang_String$object	*name;
	struct _jc_java_util_ArrayList$object	*mimeTypes;
	struct _jc_java_util_ArrayList$object	*extensions;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$refs {
    _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_refs	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_nonrefs {
	jboolean	writable;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$sub_nonrefs	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$object {
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$vtype _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24ImageFormatSpec_H_ */
